/***************************************

    This is part of frox: A simple transparent FTP proxy
    Copyright (C) 2000 James Hollingshead

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  cache.h -- header file containing the interface for cache modules.

  ***************************************/
/* --------------------------------------------------------------- **
** This file contains the following functions for each caching module:
**
** X_geninit(char **cacheopts, char *chroot);
** Called on module load. Opts is a list of config file options
** destined for the cache. chroot is the directory we are chrooted to
** - module may need to strip this from the front of any file name
** options.
**
** X_retr_start();
** Called at the start of each file retrieval. If the cache code wants
** to return the file it should return a file descriptor. If not it
** should return -1, and the RETR command will be passed on to the
** server. 
**
** X_inc_data();
** Called with each piece of incoming data. Cache code can either
** store or modify this (or both). 
**
** X_retr_end();
** Called at the end of each file retrieval to allow cleanup.
** ------------------------------------------------------------- */

#ifdef USE_LCACHE
 int l_geninit(char **cacheopts, char *chroot);
 int l_retr_start(const char *host, const char *file, const char *mdtm,
		  int size, int offset);
 void l_inc_data(char *inc, int *len);
 void l_retr_end(void);
#else
# define l_geninit NULL
# define l_retr_start NULL
# define l_inc_data NULL
# define l_retr_end NULL
#endif

#ifdef USE_HCACHE
 int s_geninit(char **cacheopts, char *chroot);
 int s_retr_start(const char *host, const char *file, const char *mdtm,
		  int size, int offst);
 void s_inc_data(char *inc, int *len);
 void s_retr_end(void);
#else
# define s_geninit NULL
# define s_retr_start NULL
# define s_inc_data NULL
# define s_retr_end NULL
#endif
